@@ -19,7 +19,6 @@
 
 #include <config.h>
 #include <gio/gio.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
 #include "app_menu_item.h"
@@ -100,17 +99,21 @@ static void
 rstto_app_menu_item_finalize(GObject *object)
 {
     RsttoAppMenuItem *menu_item = RSTTO_APP_MENU_ITEM(object);
-    if (menu_item->priv->app_info)
+    if (menu_item->priv)
     {
-        g_object_unref (menu_item->priv->app_info);
-        menu_item->priv->app_info = NULL;
+        if (menu_item->priv->app_info)
+        {
+            g_object_unref (menu_item->priv->app_info);
+            menu_item->priv->app_info = NULL;
+        }
+        if (menu_item->priv->file)
+        {
+            g_object_unref (menu_item->priv->file);
+            menu_item->priv->file = NULL;
+        }
+        g_free (menu_item->priv);
+        menu_item->priv = NULL;
     }
-    if (menu_item->priv->file)
-    {
-        g_object_unref (menu_item->priv->file);
-        menu_item->priv->file = NULL;
-    }
-
 }
 
 /**
