@@ -398,23 +398,31 @@ rstto_file_get_collate_key ( RsttoFile *r_file )
 const gchar *
 rstto_file_get_content_type ( RsttoFile *r_file )
 {
-    const gchar *content_type = NULL;
+    const gchar *file_path, *content_type = NULL;
 
     if ( NULL == r_file->priv->content_type )
     {
 #if HAVE_MAGIC_H
-        magic_t magic = magic_open(MAGIC_MIME_TYPE);
-        if ( magic != NULL )
+        magic_t magic = magic_open (MAGIC_MIME_TYPE | MAGIC_SYMLINK);
+        if ( NULL != magic )
         {
-            if ( magic_load(magic, NULL) == 0 )
+            file_path = rstto_file_get_path (r_file);
+            if ( NULL != file_path && magic_load (magic, NULL) == 0 )
             {
-                content_type = magic_file(magic, rstto_file_get_path(r_file));
+                content_type = magic_file (magic, file_path);
                 if ( NULL != content_type )
                 {
+                    /* "image/x-ms-bmp" isn't supported by gdk_pixbuf_loader_new_with_mime_type ()
+                       see https://bugzilla.xfce.org/show_bug.cgi?id=13489 */
+                    if ( g_strcmp0 (content_type, "image/x-ms-bmp") == 0 )
+                    {
+                        content_type = "image/bmp";
+                    }
+
                     r_file->priv->content_type = g_strdup (content_type);
                 }
             }
-            magic_close(magic);
+            magic_close (magic);
         }
 #endif
 
