@@ -20,6 +20,8 @@
 #ifndef __RISTRETTO_PREFERENCES_DIALOG_H__
 #define __RISTRETTO_PREFERENCES_DIALOG_H__
 
+#include <libxfce4ui/libxfce4ui.h>
+
 G_BEGIN_DECLS
 
 #define RSTTO_TYPE_PREFERENCES_DIALOG rstto_preferences_dialog_get_type()
@@ -59,7 +61,8 @@ struct _RsttoPreferencesDialogClass
     XfceTitledDialogClass  parent_class;
 };
 
-GType      rstto_preferences_dialog_get_type();
+GType
+rstto_preferences_dialog_get_type (void);
 
 GtkWidget *
 rstto_preferences_dialog_new (GtkWindow *parent);
